declare const _default: {
    /**
     * Serialize object to JSON string without empties
     *
     * @param value
     * @return
     */
    objectToJson(value: any): string;
    /**
     * Helper to hash object by algorithm
     *
     * @param algorithm
     * @param value
     * @return
     */
    hash(algorithm: string, value: string): string;
    /**
     * Trim a string/null value
     *
     * @param value
     * @return
     */
    trimValue(value: string | null | undefined): string | null;
    /**
     * Clean an string of whitespaces.
     *
     * @param value
     * @returns string | null
     */
    cleanString(value: string | null | undefined): string | null;
    /**
     * Parse or nullify amount data
     *
     * @param amount
     * @return
     */
    parseAmount(amount: number | null | undefined): string | null;
    /**
     * Verify if environment is a Browser
     */
    checkIsBrowser(): boolean;
    /**
     * Append website script and load
     *
     * @param src
     */
    addScriptToWebsite(src: string): Promise<any>;
    /**
     * Append website style
     *
     * @param id
     * @param css
     */
    addStylesById(id: string, css: string): void;
    /**
     * Append secure enrollment form to site
     *
     * @param jwt
     * @param url
     */
    addSecureForm(jwt: string, url: string): HTMLFormElement;
    /**
     * Remove HTML Element by ID if it exists.
     *
     * @param id
     */
    removeElementById(id: string): void;
    /**
     * Convert Window Size to Dimensions
     */
    convertWindowSizeToDimensions(windowSize: string | null): {
        width: string;
        height: string;
    };
};
export default _default;
