"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Helpers_1 = __importDefault(require("./Helpers"));
class Response {
    constructor() {
        /**
         * Response 'action to' format
         */
        this.action = null;
        /**
         * Response status success
         */
        this.success = false;
        /**
         * Response friendly message
         */
        this.message = null;
        /**
         * Response data payload
         */
        this.data = undefined;
        /**
         * Response input validation felds errors
         */
        this.errors = undefined;
    }
    /**
     * Define HTTP status code response
     *
     * @param status
     */
    setStatus(status) {
        this.status = status;
    }
    /**
     * Get HTTP status code
     *
     * @return
     */
    getStatus() {
        return this.status;
    }
    /**
     * Verify input has error
     *
     * @param key
     * @return
     */
    inputHasError(key) {
        if (!this.errors) {
            return false;
        }
        return this.errors.hasOwnProperty(key);
    }
    /**
     * Get data payload by key
     *
     * @param key
     * @return
     */
    getData(key) {
        if (!this.data) {
            return null;
        }
        if (!this.data.hasOwnProperty(key)) {
            return null;
        }
        return this.data[key] || null;
    }
    /**
     * Serialize object to JSON string
     *
     * @return
     */
    toJson() {
        return Helpers_1.default.objectToJson(this);
    }
}
exports.default = Response;
//# sourceMappingURL=Response.js.map