import RequestBehaviour from './RequestBehaviour';
import Response from './Response';
import Settings from '../models/Settings';
export default class ServiceBehaviour {
    /**
     * Settings service model
     */
    settings: Settings;
    /**
     * Initialize service
     */
    constructor(settings: Settings);
    /**
     * Build HTTP request to API
     *
     * @param url
     * @return
     * @throws InvalidCredentialsException
     */
    private buildRequest;
    /**
     * Mapping and cast HTTP response
     *
     * @param body
     * @param status
     * @return
     */
    parseResponse(data: any, status: number): Response;
    /**
     * Default response for exception behavior;
     *
     * @param e
     * @returns
     */
    private exceptionResponse;
    /**
     * Get API route
     *
     * @param route
     * @return
     */
    protected getRoute(route: string): string;
    /**
     * API POST request
     *
     * @param url
     * @param body
     * @return
     * @throws InvalidCredentialsException
     */
    protected post(url: string, body: RequestBehaviour): Promise<Response>;
    /**
     * API PUT request
     *
     * @param url
     * @param body
     * @return
     * @throws InvalidCredentialsException
     */
    protected put(url: string, body: RequestBehaviour): Promise<Response>;
    /**
     * API DELETE request
     *
     * @param url
     * @param body
     * @return
     * @throws InvalidCredentialsException
     */
    protected delete(url: string, body: RequestBehaviour): Promise<Response>;
    /**
     * API GET request
     *
     * @param url
     * @param body
     * @return
     * @throws InvalidCredentialsException
     */
    protected get(url: string, body: RequestBehaviour): Promise<Response>;
}
