import Response from '../base/Response';
export default class TransactionResult {
    /**
     * Transaction response type
     */
    transaction_type: string;
    /**
     * Transaction redeemed points
     */
    transaction_redeemed_points: number;
    /**
     * Approved amount on capture/sale
     */
    transaction_approved_amount: number;
    /**
     * Initial or registered transaction amount
     */
    transaction_amount: number;
    /**
     * Transaction AUTH reference code
     */
    transaction_auth: string;
    /**
     * Transacction network terminal ID
     */
    transaction_terminal: string;
    /**
     * Transaction network merchant ID
     */
    transaction_merchant: string;
    /**
     * CVV2 result response code
     */
    response_cvn: string;
    /**
     * Address verification code response
     */
    response_avs: string;
    /**
     * CAVV network evaluation result code
     */
    response_cavv: string;
    /**
     * Transaction identifier
     */
    transaction_id: string;
    /**
     * Transaction STAN, proccesor transacction identifier or transaction reference
     */
    transaction_reference: string;
    /**
     * Transaction result time
     */
    transaction_time: string;
    /**
     * Transaction result date
     */
    transaction_date: string;
    /**
     * Response is financial approved
     */
    response_approved: boolean;
    /**
     * Response fatal not completed or excecution interrupted
     */
    response_incomplete: boolean;
    /**
     * Proccesor response code
     */
    response_code: string;
    /**
     * Network response time
     */
    response_time: string;
    /**
     * Proccesor response message
     */
    response_reason: string;
    /**
     * Transaction installment type
     */
    installment_type: string;
    /**
     * Transaction installment value
     */
    installment_months: string;
    /**
     * Payment unique identifier
     */
    payment_uuid: string;
    /**
     * Payment integrity validation hash
     */
    payment_hash: string;
    /**
     * Validate if response type is valid for parse
     *
     * @param response
     * @return
     */
    static validateResponse(response: Response): boolean;
    /**
     * Convert success response to transaction entity
     *
     * @param response
     * @return
     */
    static fromResponse(response: Response): TransactionResult;
}
