"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const SuccessResponse_1 = __importDefault(require("../responses/SuccessResponse"));
const PaymentDeclinedResponse_1 = __importDefault(require("../responses/PaymentDeclinedResponse"));
const TimeoutResponse_1 = __importDefault(require("../responses/TimeoutResponse"));
class TransactionResult {
    constructor() {
        /**
         * Transaction response type
         */
        this.transaction_type = undefined;
        /**
         * Transaction redeemed points
         */
        this.transaction_redeemed_points = undefined;
        /**
         * Approved amount on capture/sale
         */
        this.transaction_approved_amount = undefined;
        /**
         * Initial or registered transaction amount
         */
        this.transaction_amount = undefined;
        /**
         * Transaction AUTH reference code
         */
        this.transaction_auth = undefined;
        /**
         * Transacction network terminal ID
         */
        this.transaction_terminal = undefined;
        /**
         * Transaction network merchant ID
         */
        this.transaction_merchant = undefined;
        /**
         * CVV2 result response code
         */
        this.response_cvn = undefined;
        /**
         * Address verification code response
         */
        this.response_avs = undefined;
        /**
         * CAVV network evaluation result code
         */
        this.response_cavv = undefined;
        /**
         * Transaction identifier
         */
        this.transaction_id = undefined;
        /**
         * Transaction STAN, proccesor transacction identifier or transaction reference
         */
        this.transaction_reference = undefined;
        /**
         * Transaction result time
         */
        this.transaction_time = undefined;
        /**
         * Transaction result date
         */
        this.transaction_date = undefined;
        /**
         * Response is financial approved
         */
        this.response_approved = undefined;
        /**
         * Response fatal not completed or excecution interrupted
         */
        this.response_incomplete = undefined;
        /**
         * Proccesor response code
         */
        this.response_code = undefined;
        /**
         * Network response time
         */
        this.response_time = undefined;
        /**
         * Proccesor response message
         */
        this.response_reason = undefined;
        /**
         * Transaction installment type
         */
        this.installment_type = undefined;
        /**
         * Transaction installment value
         */
        this.installment_months = undefined;
        /**
         * Payment unique identifier
         */
        this.payment_uuid = undefined;
        /**
         * Payment integrity validation hash
         */
        this.payment_hash = undefined;
    }
    /**
     * Validate if response type is valid for parse
     *
     * @param response
     * @return
     */
    static validateResponse(response) {
        return response instanceof SuccessResponse_1.default
            || response instanceof PaymentDeclinedResponse_1.default
            || response instanceof TimeoutResponse_1.default;
    }
    /**
     * Convert success response to transaction entity
     *
     * @param response
     * @return
     */
    static fromResponse(response) {
        const entity = new TransactionResult();
        Object.getOwnPropertyNames(response.data).map(prop => {
            if (prop in entity) {
                entity[prop] = response.data[prop];
            }
        });
        return entity;
    }
}
exports.default = TransactionResult;
//# sourceMappingURL=TransactionResult.js.map