import Response from '../base/Response';
import Settings from '../models/Settings';
import PaymentTransaction from '../requests/PaymentTransaction';
import CardinalAuthentication from '../services/CardinalAuthentication';
declare global {
    interface Window {
        Cardinal: any;
    }
}
export default class CardinalManager {
    /**
     * Settings service model
     */
    settings: Settings;
    /**
     * Cardinal authentication service
     */
    service: CardinalAuthentication;
    /**
     * Payment transaction
     */
    transaction: PaymentTransaction;
    /**
     * PixelPay transaction authentication identifier
     */
    identifier: string;
    /**
     * Direct API URL for data collection
     */
    collection_url: string;
    /**
     * Direct API transaction flag
     */
    direct_api: boolean;
    /**
     * Listener for Cardinal Direct API messages
     */
    listen_direct_message: (event: MessageEvent) => Promise<void>;
    /**
     * Resolve promise when direct API transaction is complete
     */
    direct_api_resolve: (value: Response | PromiseLike<Response>) => void;
    /**
     * Resolve promise when direct API transaction fails
     */
    direct_api_reject: (reason?: any) => void;
    /**
     * Initialize service
     */
    constructor(settings: Settings, request: PaymentTransaction);
    /**
     * Clean all Cardinal instances
     */
    static clearAllEvents(): void;
    /**
     * Initialize manager
     *
     * @param jwt
     * @param url
     * @return
     */
    init(jwt: string, url?: string | null): Promise<Response>;
    /**
     * Cardinal transacction starting service
     */
    startCardinalTransaction(jwt_setup: string, manager: CardinalManager): Promise<Response>;
    /**
     * Start Cardinal Direct API transaction
     *
     * @param secure_form
     * @return
     */
    private startCardinalDirectApiTransaction;
    /**
     * Handle continue message from iframe.
     *
     * @param event
     */
    handleDirectApiContinue(event: MessageEvent): Promise<void>;
    /**
     * Initiate lookup message with iframe.
     *
     * @param event_data
     * @return
     */
    handleDirectApiLookup(event_data: any): Promise<void>;
    /**
     * Verify lookup response and run Cardinal attempt
     *
     * @param response
     * @param resolve
     */
    validationLookupResponse(response: Response, resolve: (value: Response | PromiseLike<Response>) => void): Promise<void>;
    /**
     * Submit Form to Iframe for Step-Up Challenge
     *
     * @param continue_url
     * @param jwt
     * @param window_size
     * @param custom_data
     */
    private submitChallengeForm;
}
