"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ServiceBehaviour_1 = __importDefault(require("../base/ServiceBehaviour"));
const PixelPayModal_1 = __importDefault(require("./PixelPayModal"));
const PixelPayLoading_1 = __importDefault(require("./PixelPayLoading"));
class PayloadManager extends ServiceBehaviour_1.default {
    /**
     * Create a new IFRAME DOM element
     *
     * @param {*} onerror
     */
    createIFrameElement(onerror) {
        const iframe = document.createElement('iframe');
        iframe.setAttribute('frameborder', '0');
        iframe.setAttribute('frameborder', '0');
        iframe.setAttribute('scrolling', 'auto');
        iframe.setAttribute('allowtransparency', 'true');
        iframe.classList.add('pixelpay-modal-iframe');
        iframe.classList.add('pixelpay-modal-loading');
        iframe.onload = () => {
            iframe.classList.remove('pixelpay-modal-loading');
        };
        iframe.onerror = onerror;
        return iframe;
    }
    /**
     * Evalua las respuestas enviadas por @method postMessage()
     * desde el servidor de la URL agregada al iFrame
     *
     * @param {object} ev
     * @param {*} resolve
     * @param {*} reject
     */
    evaluatePostMessage(ev, resolve, reject) {
        var _a;
        if (!ev || !ev.data || !ev.data.hasOwnProperty('success')) {
            return;
        }
        PixelPayModal_1.default.hide();
        if ((ev === null || ev === void 0 ? void 0 : ev.origin) == this.settings.endpoint) {
            setTimeout(() => {
                var _a, _b;
                PixelPayLoading_1.default.hide();
                resolve(this.parseResponse(ev === null || ev === void 0 ? void 0 : ev.data, ((_a = ev === null || ev === void 0 ? void 0 : ev.data) === null || _a === void 0 ? void 0 : _a.status) || (((_b = ev === null || ev === void 0 ? void 0 : ev.data) === null || _b === void 0 ? void 0 : _b.success) ? 200 : 400)));
            }, 300);
        }
        else {
            PixelPayLoading_1.default.hide();
            reject(new Error(((_a = ev === null || ev === void 0 ? void 0 : ev.data) === null || _a === void 0 ? void 0 : _a.message) || 'Payload frame response error'));
        }
    }
    /**
     * Método encargado de ejecutar al proceso de carga del Iframe
     *
     * @param {*} payload
     * @returns
     */
    loadPayload(payload) {
        return new Promise((resolve, reject) => {
            try {
                const container = document.querySelector('[without-sdk-modal]') || PixelPayModal_1.default._init().querySelector('.pixelpay-modal-container');
                if (container) {
                    const iframe = this.createIFrameElement(reject);
                    container.appendChild(iframe);
                    const iframe_document = iframe.contentWindow.document;
                    const iframe_content = atob(payload);
                    iframe_document.open();
                    iframe_document.write(iframe_content);
                    iframe_document.close();
                    window.onmessage = (ev) => {
                        this.evaluatePostMessage(ev, resolve, reject);
                    };
                }
                PixelPayModal_1.default.show();
            }
            catch (err) {
                PixelPayLoading_1.default.hide();
                reject(err);
            }
        });
    }
}
exports.default = PayloadManager;
//# sourceMappingURL=PayloadManager.js.map