"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Transaction_1 = __importDefault(require("../services/Transaction"));
const SaleTransaction_1 = __importDefault(require("../requests/SaleTransaction"));
const Settings_1 = __importDefault(require("../models/Settings"));
class RouterManager {
    /**
     * Initialize service
     */
    constructor(request) {
        this.transaction = request;
        this.transaction.source = 'router';
    }
    /**
     * Initialize manager
     */
    async init(payload) {
        const service = new Transaction_1.default(this.parsePayload(payload));
        Transaction_1.default.busy = false;
        if (this.transaction instanceof SaleTransaction_1.default) {
            return await service.doSale(this.transaction);
        }
        else {
            return await service.doAuth(this.transaction);
        }
    }
    /**
     * Parse the payload string to Object Settings
     */
    parsePayload(payload) {
        const obj_payload = JSON.parse(atob(payload));
        const settings = new Settings_1.default();
        settings.setupEnvironment(obj_payload.env);
        settings.setupCredentials(obj_payload.auth_key, obj_payload.auth_hash);
        settings.setupEndpoint(obj_payload.endpoint);
        settings.setupLanguage(this.transaction.lang);
        obj_payload.auth_user && settings.setupPlatformUser(obj_payload.auth_user);
        return settings;
    }
}
exports.default = RouterManager;
//# sourceMappingURL=RouterManager.js.map