"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Order {
    /**
     * Initialize model
     */
    constructor() {
        /**
         * Order ID
         */
        this.id = undefined;
        /**
         * Order currency code alpha-3
         */
        this.currency = undefined;
        /**
         * Order total amount
         */
        this.amount = undefined;
        /**
         * Order total tax amount
         */
        this.tax_amount = undefined;
        /**
         * Order total shipping amount
         */
        this.shipping_amount = undefined;
        /**
         * Order summary of items or products
         */
        this.content = undefined;
        /**
         * Order extra properties
         */
        this.extras = undefined;
        /**
         * Order note or aditional instructions
         */
        this.note = undefined;
        /**
         * Order calback webhook URL
         */
        this.callback_url = undefined;
        /**
         * Order customer name
         */
        this.customer_name = undefined;
        /**
         * Order customer email
         */
        this.customer_email = undefined;
        this.content = [];
        this.extras = {};
    }
    /**
     * Add item to content list of products/items
     *
     * @param item
     * @return
     */
    addItem(item) {
        this.content.push(item);
        this.totalize();
        return this;
    }
    /**
     * Add extra property to order
     *
     * @param key
     * @param value
     * @return
     */
    addExtra(key, value) {
        this.extras[key] = value;
        return this;
    }
    /**
     * Totalize order amounts and items
     *
     * @return
     */
    totalize() {
        if (!this.content.length) {
            return this;
        }
        this.amount = 0.00;
        this.tax_amount = 0.00;
        this.content.forEach(item => {
            item.totalize();
            this.amount += item.total;
            this.tax_amount += (item.tax * item.qty);
        });
        return this;
    }
}
exports.default = Order;
//# sourceMappingURL=Order.js.map