"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Helpers_1 = __importDefault(require("../base/Helpers"));
const Environment_1 = __importDefault(require("../resources/Environment"));
class Settings {
    /**
     * Initialize service
     */
    constructor() {
        /**
         * Merchant API auth key
         */
        this.auth_key = undefined;
        /**
         * Merchant API auth hash (MD5 of secret key)
         */
        this.auth_hash = undefined;
        /**
         * Merchant API platform auth user (SHA-512 of user email)
         */
        this.auth_user = undefined;
        /**
         * Merchant API endpoint URL
         */
        this.endpoint = undefined;
        /**
         * Merchant API environment
         */
        this.environment = undefined;
        /**
         * Settings response messages language
         */
        this.lang = undefined;
        /**
         * SDK identifier
         */
        this.sdk = undefined;
        /**
         * SDK identifier
         */
        this.sdk_version = undefined;
        this.endpoint = 'https://pixelpay.app';
    }
    /**
     * Setup API endpoint URL
     *
     * @param endpoint
     */
    setupEndpoint(endpoint) {
        this.endpoint = endpoint;
    }
    /**
     * Setup API credentials
     *
     * @param key
     * @param hash
     */
    setupCredentials(key, hash) {
        this.auth_key = key;
        this.auth_hash = hash;
    }
    /**
     * Setup API platform user
     *
     * @param hash
     */
    setupPlatformUser(hash) {
        this.auth_user = hash;
    }
    /**
     * Setup API environment
     *
     * @param env
     */
    setupEnvironment(env) {
        this.environment = env;
    }
    /**
     * Setup defaults to Sandbox credentials
     */
    setupSandbox() {
        this.endpoint = 'https://pixel-pay.com';
        this.auth_key = '1234567890';
        this.auth_hash = Helpers_1.default.hash('MD5', '@s4ndb0x-abcd-1234-n1l4-p1x3l');
        this.environment = Environment_1.default.SANDBOX;
    }
    /**
     * Setup response messages language
     *
     * @param lang
     */
    setupLanguage(lang) {
        this.lang = lang;
    }
}
exports.default = Settings;
//# sourceMappingURL=Settings.js.map