"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const RequestBehaviour_1 = __importDefault(require("../base/RequestBehaviour"));
const Helpers_1 = __importDefault(require("../base/Helpers"));
class CardTokenization extends RequestBehaviour_1.default {
    constructor() {
        super(...arguments);
        /**
         * Card number or PAN
         */
        this.number = null;
        /**
         * Card security code
         */
        this.cvv2 = null;
        /**
         * Card expire month date (MM)
         */
        this.expire_month = null;
        /**
         * Card expire year date (YYYY)
         */
        this.expire_year = null;
        /**
         * Cardholder name
         */
        this.cardholder = null;
        /**
         * Customer billing address
         */
        this.address = null;
        /**
         * Customer billing country alpha-2 code (ISO 3166-1)
         */
        this.country = null;
        /**
         * Customer billing state alpha code (ISO 3166-2)
         */
        this.state = null;
        /**
         * Customer billing city
         */
        this.city = null;
        /**
         * Customer billing postal code
         */
        this.zip = null;
        /**
         * Customer billing phone
         */
        this.phone = null;
        /**
         * Customer email
         */
        this.email = null;
    }
    /**
     * Associate and mapping Card model properties to transaction
     *
     * @param card
     */
    setCard(card) {
        this.number = Helpers_1.default.cleanString(card.number);
        this.cvv2 = card.cvv2;
        this.cardholder = Helpers_1.default.trimValue(card.cardholder);
        if (card.expire_month) {
            this.expire_month = ('00' + card.expire_month).slice(-2);
        }
        if (card.expire_year) {
            this.expire_year = String(card.expire_year);
        }
    }
    /**
     * Associate and mapping Billing model properties to transaction
     *
     * @param billing
     */
    setBilling(billing) {
        this.address = Helpers_1.default.trimValue(billing.address);
        this.country = billing.country;
        this.state = billing.state;
        this.city = Helpers_1.default.trimValue(billing.city);
        this.zip = billing.zip;
        this.phone = billing.phone;
    }
}
exports.default = CardTokenization;
//# sourceMappingURL=CardTokenization.js.map