import RequestBehaviour from '../base/RequestBehaviour';
import PaymentTransaction from '../requests/PaymentTransaction';
export default class LookupTransaction extends RequestBehaviour {
    /**
     * Tokenized card identifier (T-* format)
     */
    card_token: string;
    /**
     * Card number or PAN
     */
    card_number: string;
    /**
     * Card security code
     */
    card_cvv: string;
    /**
     * Card expire year/month date (YYMM)
     */
    card_expire: string;
    /**
     * Customer billing address
     */
    billing_address: string;
    /**
     * Customer billing country alpha-2 code (ISO 3166-1)
     */
    billing_country: string;
    /**
     * Customer billing state alpha code (ISO 3166-2)
     */
    billing_state: string;
    /**
     * Customer billing city
     */
    billing_city: string;
    /**
     * Customer billing postal code
     */
    billing_zip: string;
    /**
     * Customer billing phone
     */
    billing_phone: string;
    /**
     * Order customer name
     */
    customer_name: string;
    /**
     * Order customer email
     */
    customer_email: string;
    /**
     * Order ID
     */
    order_id: string;
    /**
     * Order currency code alpha-3
     */
    order_currency: string;
    /**
     * Order total amount
     */
    order_amount: string;
    /**
     * Indicates the maximum number of authorizations for installment payments.
     */
    installment: string;
    /**
     * Secure payload for transactions
     */
    secure_payload: string;
    /**
     * Cardinal session reference
     */
    reference: string;
    /**
     * Ability of the cardholder browser to execute Java.
     */
    browser_java_enabled: string;
    /**
     *  Exact content of the HTTP accept headers sent from the cardholder's browser.
     */
    browser_header: string;
    /**
     * Browser language as defined in IETF BCP47 .
     */
    browser_language: string;
    /**
     * The bit depth of the color palette for displaying images, in bits per pixel
     */
    browser_color_depth: string;
    /**
     * Total height of the Cardholder's scree in pixels
     */
    browser_screen_height: string;
    /**
     * Total width of the Cardholder's scree in pixels
     */
    browser_screen_width: string;
    /**
     * Time difference between UTC time and the cardholder browser local time, in minutes
     */
    browser_time_zone: string;
    /**
     *  The exact content of the HTTP user agent header.
     */
    user_agent: string;
    /**
     * The IP address of the Consumer.
     */
    ip_address: string;
    /**
     * Cardinal device channel (SDK or Browser)
     */
    device_channel: string;
    /**
     * Ability of the cardholder browser to execute JavaScript.
     */
    browser_javascript_enabled: string;
    /**
     * Cardinal authentication flag for tokenization
     */
    authenticate_token: boolean;
    /**
     * Cast PaymentTransaction to LookupTransaction
     */
    fromPaymentTransaction(request: PaymentTransaction): void;
    /**
     * Check if required EMV fields were included by songbird. If not, they are added manually.
     */
    setRequiredEMVFields(): void;
}
