"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const RequestBehaviour_1 = __importDefault(require("../base/RequestBehaviour"));
const AuthTokenization_1 = __importDefault(require("./AuthTokenization"));
const SaleTransaction_1 = __importDefault(require("./SaleTransaction"));
class LookupTransaction extends RequestBehaviour_1.default {
    constructor() {
        super(...arguments);
        /**
         * Tokenized card identifier (T-* format)
         */
        this.card_token = null;
        /**
         * Card number or PAN
         */
        this.card_number = null;
        /**
         * Card security code
         */
        this.card_cvv = null;
        /**
         * Card expire year/month date (YYMM)
         */
        this.card_expire = null;
        /**
         * Customer billing address
         */
        this.billing_address = null;
        /**
         * Customer billing country alpha-2 code (ISO 3166-1)
         */
        this.billing_country = null;
        /**
         * Customer billing state alpha code (ISO 3166-2)
         */
        this.billing_state = null;
        /**
         * Customer billing city
         */
        this.billing_city = null;
        /**
         * Customer billing postal code
         */
        this.billing_zip = null;
        /**
         * Customer billing phone
         */
        this.billing_phone = null;
        /**
         * Order customer name
         */
        this.customer_name = null;
        /**
         * Order customer email
         */
        this.customer_email = null;
        /**
         * Order ID
         */
        this.order_id = null;
        /**
         * Order currency code alpha-3
         */
        this.order_currency = null;
        /**
         * Order total amount
         */
        this.order_amount = null;
        /**
         * Indicates the maximum number of authorizations for installment payments.
         */
        this.installment = null;
        /**
         * Secure payload for transactions
         */
        this.secure_payload = null;
        /**
         * Cardinal session reference
         */
        this.reference = null;
        /**
         * Ability of the cardholder browser to execute Java.
         */
        this.browser_java_enabled = 'false';
        /**
         *  Exact content of the HTTP accept headers sent from the cardholder's browser.
         */
        this.browser_header = null;
        /**
         * Browser language as defined in IETF BCP47 .
         */
        this.browser_language = null;
        /**
         * The bit depth of the color palette for displaying images, in bits per pixel
         */
        this.browser_color_depth = null;
        /**
         * Total height of the Cardholder's scree in pixels
         */
        this.browser_screen_height = null;
        /**
         * Total width of the Cardholder's scree in pixels
         */
        this.browser_screen_width = null;
        /**
         * Time difference between UTC time and the cardholder browser local time, in minutes
         */
        this.browser_time_zone = null;
        /**
         *  The exact content of the HTTP user agent header.
         */
        this.user_agent = null;
        /**
         * The IP address of the Consumer.
         */
        this.ip_address = null;
        /**
         * Cardinal device channel (SDK or Browser)
         */
        this.device_channel = 'Browser';
        /**
         * Ability of the cardholder browser to execute JavaScript.
         */
        this.browser_javascript_enabled = 'true';
        /**
         * Cardinal authentication flag for tokenization
         */
        this.authenticate_token = false;
    }
    /**
     * Cast PaymentTransaction to LookupTransaction
     */
    fromPaymentTransaction(request) {
        this.card_token = request.card_token;
        this.card_number = request.card_number;
        this.card_expire = request.card_expire;
        this.billing_address = request.billing_address;
        this.billing_country = request.billing_country;
        this.billing_state = request.billing_state;
        this.billing_city = request.billing_city;
        this.billing_zip = request.billing_zip;
        this.billing_phone = request.billing_phone;
        this.customer_name = request.customer_name;
        this.customer_email = request.customer_email;
        this.order_id = request.order_id;
        this.order_currency = request.order_currency;
        this.order_amount = request.order_amount;
        this.secure_payload = request.secure_payload;
        this.authenticate_token = request instanceof AuthTokenization_1.default;
        if (request instanceof SaleTransaction_1.default) {
            this.installment = request.installment_months;
        }
    }
    /**
     * Check if required EMV fields were included by songbird. If not, they are added manually.
     */
    setRequiredEMVFields() {
        if (!this.browser_java_enabled) {
            this.browser_java_enabled = typeof navigator.javaEnabled === "function"
                ? navigator.javaEnabled().toString()
                : 'false';
        }
        if (!this.browser_language) {
            this.browser_language = navigator.language;
        }
        if (!this.browser_color_depth) {
            this.browser_color_depth = screen.colorDepth.toString();
        }
        if (!this.browser_screen_height) {
            this.browser_screen_height = screen.height.toString() || window.innerHeight.toString();
        }
        if (!this.browser_screen_width) {
            this.browser_screen_width = screen.width.toString() || window.innerWidth.toString();
        }
        if (!this.browser_time_zone) {
            this.browser_time_zone = (new Date()).getTimezoneOffset().toString();
        }
        if (!this.user_agent) {
            this.user_agent = navigator.userAgent;
        }
    }
}
exports.default = LookupTransaction;
//# sourceMappingURL=LookupTransaction.js.map