import Item from '../models/Item';
import Order from '../models/Order';
import Card from '../models/Card';
import Billing from '../models/Billing';
import RequestBehaviour from '../base/RequestBehaviour';
export default class PaymentTransaction extends RequestBehaviour {
    /**
     * Payment UUID
     */
    payment_uuid: string;
    /**
     * Tokenized card identifier (T-* format)
     */
    card_token: string;
    /**
     * Card number or PAN
     */
    card_number: string;
    /**
     * Card security code
     */
    card_cvv: string;
    /**
     * Card expire year/month date (YYMM)
     */
    card_expire: string;
    /**
     * Cardholder name
     */
    card_holder: string;
    /**
     * Customer billing address
     */
    billing_address: string;
    /**
     * Customer billing country alpha-2 code (ISO 3166-1)
     */
    billing_country: string;
    /**
     * Customer billing state alpha code (ISO 3166-2)
     */
    billing_state: string;
    /**
     * Customer billing city
     */
    billing_city: string;
    /**
     * Customer billing postal code
     */
    billing_zip: string;
    /**
     * Customer billing phone
     */
    billing_phone: string;
    /**
     * Order customer name
     */
    customer_name: string;
    /**
     * Order customer email
     */
    customer_email: string;
    /**
     * Order customer device fingerprint
     */
    customer_fingerprint: string;
    /**
     * Order ID
     */
    order_id: string;
    /**
     * Order currency code alpha-3
     */
    order_currency: string;
    /**
     * Order total amount
     */
    order_amount: string;
    /**
     * Order total tax amount
     */
    order_tax_amount: string;
    /**
     * Order total shipping amount
     */
    order_shipping_amount: string;
    /**
     * Order summary of items or products
     */
    order_content: Array<Item>;
    /**
     * Order extra properties
     */
    order_extras: Object;
    /**
     * Order note or aditional instructions
     */
    order_note: string;
    /**
     * Order calback webhook URL
     */
    order_callback: string;
    /**
     * Activate authentication request (3DS/EMV)
     */
    authentication_request: boolean;
    /**
     * Authentication transaction identifier
     */
    authentication_identifier: string;
    /**
     * Secure payload for transactions
     */
    secure_payload: string;
    /**
     * Internal processing flow of the transaction (e.g. router, proxy, etc)
     */
    source: string;
    /**
     * Associate and mapping Card model properties to transaction
     *
     * @param card
     */
    setCard(card: Card): void;
    /**
     * Associate and mapping CardToken model properties to transaction
     *
     * @param token
     */
    setCardToken(token?: string): void;
    /**
     * Associate and mapping Billing model properties to transaction
     *
     * @param billing
     */
    setBilling(billing: Billing): void;
    /**
     * Associate and mapping Order model properties to transaction
     *
     * @param order
     */
    setOrder(order: Order): void;
    /**
     * Enable 3DS/EMV authentication request
     */
    withAuthenticationRequest(): void;
}
