"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Helpers_1 = __importDefault(require("../base/Helpers"));
const RequestBehaviour_1 = __importDefault(require("../base/RequestBehaviour"));
class PaymentTransaction extends RequestBehaviour_1.default {
    constructor() {
        super(...arguments);
        /**
         * Payment UUID
         */
        this.payment_uuid = null;
        /**
         * Tokenized card identifier (T-* format)
         */
        this.card_token = null;
        /**
         * Card number or PAN
         */
        this.card_number = null;
        /**
         * Card security code
         */
        this.card_cvv = null;
        /**
         * Card expire year/month date (YYMM)
         */
        this.card_expire = null;
        /**
         * Cardholder name
         */
        this.card_holder = null;
        /**
         * Customer billing address
         */
        this.billing_address = null;
        /**
         * Customer billing country alpha-2 code (ISO 3166-1)
         */
        this.billing_country = null;
        /**
         * Customer billing state alpha code (ISO 3166-2)
         */
        this.billing_state = null;
        /**
         * Customer billing city
         */
        this.billing_city = null;
        /**
         * Customer billing postal code
         */
        this.billing_zip = null;
        /**
         * Customer billing phone
         */
        this.billing_phone = null;
        /**
         * Order customer name
         */
        this.customer_name = null;
        /**
         * Order customer email
         */
        this.customer_email = null;
        /**
         * Order customer device fingerprint
         */
        this.customer_fingerprint = null;
        /**
         * Order ID
         */
        this.order_id = null;
        /**
         * Order currency code alpha-3
         */
        this.order_currency = null;
        /**
         * Order total amount
         */
        this.order_amount = null;
        /**
         * Order total tax amount
         */
        this.order_tax_amount = null;
        /**
         * Order total shipping amount
         */
        this.order_shipping_amount = null;
        /**
         * Order summary of items or products
         */
        this.order_content = [];
        /**
         * Order extra properties
         */
        this.order_extras = {};
        /**
         * Order note or aditional instructions
         */
        this.order_note = null;
        /**
         * Order calback webhook URL
         */
        this.order_callback = null;
        /**
         * Activate authentication request (3DS/EMV)
         */
        this.authentication_request = false;
        /**
         * Authentication transaction identifier
         */
        this.authentication_identifier = null;
        /**
         * Secure payload for transactions
         */
        this.secure_payload = null;
        /**
         * Internal processing flow of the transaction (e.g. router, proxy, etc)
         */
        this.source = null;
    }
    /**
     * Associate and mapping Card model properties to transaction
     *
     * @param card
     */
    setCard(card) {
        this.card_number = Helpers_1.default.cleanString(card.number);
        this.card_cvv = card.cvv2;
        this.card_expire = card.getExpireFormat();
        this.card_holder = Helpers_1.default.trimValue(card.cardholder);
    }
    /**
     * Associate and mapping CardToken model properties to transaction
     *
     * @param token
     */
    setCardToken(token = null) {
        this.card_token = token;
    }
    /**
     * Associate and mapping Billing model properties to transaction
     *
     * @param billing
     */
    setBilling(billing) {
        this.billing_address = Helpers_1.default.trimValue(billing.address);
        this.billing_country = billing.country;
        this.billing_state = billing.state;
        this.billing_city = Helpers_1.default.trimValue(billing.city);
        this.billing_zip = billing.zip;
        this.billing_phone = billing.phone;
    }
    /**
     * Associate and mapping Order model properties to transaction
     *
     * @param order
     */
    setOrder(order) {
        this.order_id = order.id;
        this.order_currency = order.currency;
        this.order_amount = Helpers_1.default.parseAmount(order.amount);
        this.order_tax_amount = Helpers_1.default.parseAmount(order.tax_amount);
        this.order_shipping_amount = Helpers_1.default.parseAmount(order.shipping_amount);
        this.order_content = order.content;
        this.order_extras = order.extras;
        this.order_note = Helpers_1.default.trimValue(order.note);
        this.order_callback = order.callback_url;
        this.customer_name = Helpers_1.default.trimValue(order.customer_name);
        this.customer_email = order.customer_email;
    }
    /**
     * Enable 3DS/EMV authentication request
     */
    withAuthenticationRequest() {
        this.authentication_request = true;
    }
}
exports.default = PaymentTransaction;
//# sourceMappingURL=PaymentTransaction.js.map