import Response from '../base/Response';
import ServiceBehaviour from '../base/ServiceBehaviour';
import CardTokenization from '../requests/CardTokenization';
import AuthTokenization from '../requests/AuthTokenization';
export default class Tokenization extends ServiceBehaviour {
    /**
     * Vault credit/debit card and obtain a token card identifier (T-* format)
     *
     * @param card
     * @return
     * @throws InvalidCredentialsException
     */
    vaultCard(card: CardTokenization): Promise<Response>;
    /**
     * Authenticate card by token card identifier (T-* format)
     *
     * @param authentication
     * @return
     * @throws InvalidCredentialsException
     * @throws InvalidTransactionTypeException
     */
    authCard(authentication: AuthTokenization): Promise<Response>;
    /**
     * Update credit/debit card by token card identifier
     *
     * @param token
     * @param card
     * @return
     * @throws InvalidCredentialsException
     */
    updateCard(token: string, card: CardTokenization): Promise<Response>;
    /**
     * Show credit/debit card metadata by token card identifier
     *
     * @param token
     * @return
     * @throws InvalidCredentialsException
     */
    showCard(token: string): Promise<Response>;
    /**
     * Show credit/debit card metadata by token card identifier
     *
     * @param token
     * @return
     * @throws InvalidCredentialsException
     */
    showCards(tokens: string[]): Promise<Response>;
    /**
     * Delete credit/debit card metadata by token card identifier
     *
     * @param token
     * @return
     * @throws InvalidCredentialsException
     */
    deleteCard(token: string): Promise<Response>;
}
