import Response from "../base/Response";
import ServiceBehaviour from '../base/ServiceBehaviour';
import SaleTransaction from '../requests/SaleTransaction';
import AuthTransaction from '../requests/AuthTransaction';
import CaptureTransaction from '../requests/CaptureTransaction';
import VoidTransaction from '../requests/VoidTransaction';
import StatusTransaction from '../requests/StatusTransaction';
import Settings from '../models/Settings';
export default class Transaction extends ServiceBehaviour {
    /**
     * Define if there's a transaction currently running
     */
    static busy: boolean;
    /**
     * Define if concurrent transactions should be allowed
     */
    static concurrent: boolean;
    /**
     * Initialize service
     */
    constructor(settings: Settings);
    /**
     * Enable concurrent transactions
     */
    static withConcurrency(): void;
    /**
     * Send and proccesing SALE transaction
     *
     * @param transaction
     * @return
     * @throws InvalidCredentialsException
     */
    doSale(transaction: SaleTransaction): Promise<Response>;
    /**
     * Send and proccesing AUTH transaction
     *
     * @param transaction
     * @return
     * @throws InvalidCredentialsException
     */
    doAuth(transaction: AuthTransaction): Promise<Response>;
    /**
     * Send and proccesing CAPTURE transaction
     *
     * @param transaction
     * @return
     * @throws InvalidCredentialsException
     */
    doCapture(transaction: CaptureTransaction): Promise<Response>;
    /**
     * Send and proccesing VOID transaction
     *
     * @param transaction
     * @return
     * @throws InvalidCredentialsException
     */
    doVoid(transaction: VoidTransaction): Promise<Response>;
    /**
     * Send and proccesing SALE transaction
     *
     * @param transaction
     * @return
     * @throws InvalidCredentialsException
     */
    getStatus(transaction: StatusTransaction): Promise<Response>;
    /**
     * Verify a payment hash and returns true if payment response is not modified
     *
     * @param hash
     * @param order_id
     * @param secret
     * @return
     */
    verifyPaymentHash(hash: string, order_id: string, secret: string): boolean;
    /**
     * Get Cybersource Decision Manager Fingerprint
     *
     * @param merchant_id
     * @param org_id
     * @param callback
     */
    getCybersourceFingerprint(merchant_id: string, org_id: string): string;
}
