import Item from '../../src/models/Item';
import Order from '../../src/models/Order'

test('Order shoul be empty', () => {
    let order: Order = new Order();

    expect(order.id).toBe(undefined)
    expect(order.currency).toBe(undefined)
    expect(order.amount).toBe(undefined)
    expect(order.tax_amount).toBe(undefined)
    expect(order.shipping_amount).toBe(undefined)
    expect(order.content).toStrictEqual([])
    expect(order.extras).toStrictEqual({})
    expect(order.note).toBe(undefined)
    expect(order.callback_url).toBe(undefined)
    expect(order.customer_name).toBe(undefined)
    expect(order.customer_email).toBe(undefined)
})

test('Order with empty item', () => {
    let order: Order = new Order();
    let item = new Item();

    order.amount = 10.00;
    order.addItem(item);

    order.totalize();
    expect(order.amount).toEqual(0.00)
})

test('Order with items', () => {
    let order: Order = new Order();
    let item = new Item();
    const price = 12.00;
    const qty = 10;
    const tax = 3;

    order.amount = 10.00;
    
    item.code = 'x10';
    item.price = price;
    item.qty = qty;
    item.tax = tax;
    item.title = "Test item";
    item.total = 10;
    item.totalize();
    expect(item.total).toEqual(price * qty);

    order.addItem(item);
    order.totalize();
    expect(order.amount).toEqual(price * qty);
    expect(order.tax_amount).toEqual(tax * qty);
})

test('Add extra info to order', () => {
    let order: Order = new Order();
    order.addExtra('user_id', 1);
    order.addExtra('user_name', "Jhon");
    order.addExtra('user_last_name', "Doe");

    expect(order.extras.hasOwnProperty("user_id")).toBe(true);
    expect(order.extras.hasOwnProperty("user_name")).toBe(true);
    expect(order.extras.hasOwnProperty("user_last_name")).toBe(true);
})