import Settings from '../../src/models/Settings';


test("Default settings", () => {
    let settings: Settings = new Settings();
    expect(settings.endpoint).toEqual("https://pixelpay.app");
    expect(settings.auth_key).toEqual(undefined)
    expect(settings.auth_hash).toEqual(undefined)
    expect(settings.auth_user).toEqual(undefined)
    expect(settings.environment).toEqual(undefined)
    expect(settings.lang).toEqual(undefined)
})

test('Setup endpoint', () => {
    let settings: Settings = new Settings();
    let staging = 'https://pixel-pay.com';
    expect(settings.endpoint).toEqual("https://pixelpay.app");
    settings.setupEndpoint(staging);
    expect(settings.endpoint).toEqual(staging);
})

test('Setup credentials', () => {
    let settings: Settings = new Settings();
    let hash = "12345678945612345678912345679";
    let key = "1234567890";
    settings.setupCredentials(key, hash);
    expect(settings.auth_key).toEqual(key);
    expect(settings.auth_hash).toEqual(hash);
})

test('Setup platform user', () => {
    let settings: Settings = new Settings();
    let user = '123457890';
    settings.setupPlatformUser(user);
    expect(settings.auth_user).toEqual(user);
})

test('Setup enviroment', () => {
    let settings: Settings = new Settings();
    let sandbox = "sandbox";
    settings.environment = sandbox;
    expect(settings.environment).toEqual(sandbox);
})

test('Setup setupSandbox', () => {
    let settings: Settings = new Settings();
    let staging = 'https://pixel-pay.com';
    let hash = "36cdf8271723276cb6f94904f8bde4b6";
    let key = "1234567890";
    let sandbox = "sandbox";

    settings.setupSandbox();
    expect(settings.endpoint).toEqual(staging);
    expect(settings.auth_key).toEqual(key);
    expect(settings.auth_hash).toEqual(hash);
    expect(settings.environment).toEqual(sandbox);

})

test('Setup language', () => {
    let settings: Settings = new Settings();
    let lang = 'es';
    settings.setupLanguage(lang);
    expect(settings.lang).toEqual(lang);
})

test('Inherith Signature', () => {
    let settings: Settings = new Settings();

    const sdk = "sdk-test";
    const sdk_version = "unreleased";

    settings.sdk = sdk;
    settings.sdk_version = sdk_version;

    expect(settings.sdk).toEqual(sdk);
    expect(settings.sdk_version).toEqual(sdk_version);
})
